Package: psy
Title: Various Procedures Used in Psychometrics
Version: 1.2
Authors@R: 
     person("Bruno", "Falissard", email="falissard_b@wanadoo.fr", role = c("aut","cre"))
Description: Kappa, ICC, reliability coefficient, parallel analysis, 
     multi-traits multi-methods, spherical representation of a correlation matrix.
License: GPL (>= 2)
Encoding: UTF-8
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2022-04-21 13:20:08 UTC; Bruno
Author: Bruno Falissard [aut, cre]
Maintainer: Bruno Falissard <falissard_b@wanadoo.fr>
Repository: CRAN
Date/Publication: 2022-04-21 22:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 21:23:42 UTC; unix
