# Generated by roxygen2: do not edit by hand

export(ckappa)
export(cronbach)
export(fpca)
export(icc)
export(lkappa)
export(mdspca)
export(mtmm)
export(scree.plot)
export(sphpca)
export(wkappa)
importFrom(grDevices,dev.new)
importFrom(graphics,abline)
importFrom(graphics,boxplot)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,stripchart)
importFrom(graphics,symbols)
importFrom(graphics,text)
importFrom(stats,anova)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.extract)
importFrom(stats,na.omit)
importFrom(stats,optim)
importFrom(stats,reshape)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,var)
